/**
 * Vue mixin containing code getting the respective vue component for event additional fields.
 *
 * Only used by event registration form, but factored out for readability.
 */

// TODO: add some more rule checking (e.g. for emails)

import DateField from "aleksis.core/components/generic/forms/DateField.vue";
import DateTimeField from "aleksis.core/components/generic/forms/DateTimeField.vue";
import TimeField from "aleksis.core/components/generic/forms/TimeField.vue";
import PositiveSmallIntegerField from "aleksis.core/components/generic/forms/PositiveSmallIntegerField.vue";

const eventAdditionalFieldMixin = {
  methods: {
    fieldComponentForAdditionalField(additionalField) {
      if (
        additionalField.fieldType == "CHARFIELD" ||
        additionalField.fieldType == "EMAILFIELD" ||
        additionalField.fieldType == "URLFIELD" ||
        additionalField.fieldType == "GENERICIPADDRESSFIELD"
      ) {
        return "v-text-field";
      } else if (
        additionalField.fieldType == "BOOLEANFIELD" ||
        additionalField.fieldType == "NULLBOOLEANFIELD"
      ) {
        // TODO: implement proper null boolean input
        return "v-checkbox";
      } else if (additionalField.fieldType == "DATEFIELD") {
        return DateField;
      } else if (additionalField.fieldType == "DATETIMEFIELD") {
        return DateTimeField;
      } else if (additionalField.fieldType == "TIMEFIELD") {
        return TimeField;
      } else if (
        additionalField.fieldType == "INTEGERFIELD" ||
        additionalField.fieldType == "DECIMALFIELD"
      ) {
        // TODO: implement proper decimal input
        return PositiveSmallIntegerField;
      }
      return "";
    },
  },
};

export default eventAdditionalFieldMixin;
